@@ -17,7 +17,7 @@ def zpv():
     return [[0., 0., 0.],
             [0., 0., 0.]]
 
-def ir():
+def zr():
     '''Initialize an r-matrix to the null matrix.'''
     return [[0., 0., 0.],
             [0., 0., 0.],
@@ -214,4 +214,4 @@ __all__ = ['ASTROM', 'AULT', 'CMPS', 'D2PI', 'DAS2R', 'DAU', 'DAYSEC',
            'tcgtt', 'tdbtcb', 'tdbtt', 'tf2a', 'tf2d', 'tr', 'trxp',
            'trxpv', 'tttai', 'tttcg', 'tttdb', 'ttut1', 'ut1tai',
            'ut1tt', 'ut1utc', 'utctai', 'utcut1', 'xy06', 'xys00a',
-           'xys00b', 'xys06a', 'zp', 'zpv']
+           'xys00b', 'xys06a', 'zp', 'zpv', 'zr']
